
#ifndef _C12_ds554_
#define _C12_ds554_

#ifdef __cplusplus
extern "C" {
#endif

extern void F1092_7293(EIF_REFERENCE, EIF_REFERENCE);
extern void EIF_Minit554(void);
extern char *(*R1053[])();

#ifdef __cplusplus
}
#endif

#endif
